breed [televisions television]
breed [newspapers newspaper]
breed [influencers influencer]
breed [banners banner]
breed [persons person]
persons-own [age influencer-influence newspaper-influence television-influence excitement banner-influence]

to setup
  clear-all
  reset-ticks

  set-default-shape influencers "youtube"
  set-default-shape televisions "television"
  set-default-shape newspapers "newspaper-2"
  set-default-shape banners "banner"

  generate-newspapers (abs (number-of-newspapers / price))
  generate-televisions (abs (number-of-televisions / price))
  generate-influencers (abs (number-of-influencers / price))
  generate-banners (abs (number-of-banners / price))

  generate-persons 10 "18-24"
  generate-persons 10 "24-34"
  generate-persons 10 "34-44"
  generate-persons 10 "44-54"
  generate-persons 10 "old"


 ask persons [
    update-influence
  ]


  ask patches [
    set pcolor 9 ;Light gray
  ]

end

to go
  if ticks >= total-ticks [user-message "Det antal ticks du har betalt for er gået" stop ]


  ask (turtle-set newspapers televisions influencers banners) [
    move
  ]

  ask persons [
    move
    update-influence
  ]


  tick
end

to move  ; turtle procedure
  right random 50
  left random 50
  forward 1
end


to-report total-ticks
  ifelse  count turtles = 50 [report ressources] ;There are no added media to the model
  [report ressources / (number-of-televisions + number-of-newspapers + number-of-influencers + number-of-banners)]
end

to-report ressources
  report price * 50000
end

to update-influence

  let influencers-in-radius count influencers in-radius 1
  let banners-in-radius count banners in-radius 1
  let newspapers-in-radius count newspapers in-radius 1
  let television-in-radius count televisions in-radius 1

  set excitement excitement + (influencers-in-radius * influencer-influence) + (newspapers-in-radius * newspaper-influence) + (television-in-radius * television-influence + banners-in-radius * banner-influence) * 5

  if excitement < 255 [
    set color (list excitement 0 0)
  ]

end



to generate-televisions [number] ; Puts televisions into the world with correct color and random position
  create-televisions number [
    set size 3
    set color blue
    set-position
  ]
end


to generate-newspapers [number] ; Puts newspapers into the world with correct color and random position
  create-newspapers number [
    set size 3
    set color gray
    set-position
  ]
end

to generate-influencers [number] ; Puts youtubes into the world with correct color and random position
  create-influencers number [
    set size 3
    set-position
  ]
end

to generate-banners [number] ; Puts youtubes into the world with correct color and random position
  create-banners number [
    set size 3
    set-position
    set color orange
  ]
end

to generate-persons [number person-age] ; puts persons into the world

  create-persons number [
    set-position
    set size 3
    set age person-age

    set color gray

    (ifelse

      age = "18-24" [
        set shape "person-young"
        set influencer-influence 1
        set television-influence 0.2
        set newspaper-influence 0
        set banner-influence 0.5
      ]
      age = "24-34" [
        set shape "person-child"
        set influencer-influence 0.4
        set television-influence 0.3
        set newspaper-influence 0.0
        set banner-influence 0.7
      ]
      age = "34-44" [
        set shape "person-adult"
        set influencer-influence 0.1
        set television-influence 0.5
        set newspaper-influence 0.1
        set banner-influence 0.8

      ]

      age = "44-54" [
        set shape "person-ultraadult"
        set influencer-influence 0
        set television-influence 0.8
        set newspaper-influence 0.2
        set banner-influence 0.4

      ]

      [
        set shape "person-old"
        set influencer-influence 0
        set television-influence 1
        set newspaper-influence 0.3
        set banner-influence 0.3

    ])
  ]


end

to set-position  ; Turtle procedure

  setxy random-pxcor random-pycor
  set heading random 360

end

to-report price

  report 50000

end


to-report average-excitement [agentset]
  ifelse count agentset > 0 [
    report sum [excitement] of agentset / count agentset
  ] [report 0]
end
@#$#@#$#@
GRAPHICS-WINDOW
234
14
671
452
-1
-1
13.0
1
10
1
1
1
0
1
1
1
-16
16
-16
16
0
0
1
ticks
30.0

SLIDER
18
33
212
66
number-of-televisions
number-of-televisions
0
1000000
1000000.0
50000
1
NIL
HORIZONTAL

SLIDER
17
82
207
115
number-of-newspapers
number-of-newspapers
0
1000000
0.0
50000
1
NIL
HORIZONTAL

BUTTON
15
225
81
258
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
107
227
170
260
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
17
127
194
160
number-of-influencers
number-of-influencers
0
1000000
0.0
50000
1
NIL
HORIZONTAL

SLIDER
16
175
195
208
number-of-banners
number-of-banners
0
1000000
0.0
50000
1
NIL
HORIZONTAL

MONITOR
27
300
139
345
Number of ticks
total-ticks
17
1
11

PLOT
687
42
1015
275
Påvirkning af aldersgrupper
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"18-24" 1.0 0 -2674135 true "" "plot average-excitement persons with [age = \"18-24\"]"
"24-34" 1.0 0 -14454117 true "" "plot average-excitement persons with [age = \"24-34\"]"
"34-44" 1.0 0 -11085214 true "" "plot average-excitement persons with [age = \"34-44\"]"
"44-54" 1.0 0 -5825686 true "" "plot average-excitement persons with [age = \"44-54\"]"
"Ældre end 54" 1.0 0 -1184463 true "" "plot average-excitement persons with [age = \"old\"]"

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

banner
true
0
Rectangle -7500403 true true 15 119 291 198
Line -13840069 false 120 180 120 180
Line -13840069 false 128 132 128 132
Polygon -13840069 true false 211 168
Polygon -7500403 true true 30 136 30 147 49 137
Polygon -7500403 true true 32 167 32 184 51 170
Polygon -7500403 true true 75 132 89 160
Polygon -13840069 true false 68 136 69 181 98 181 100 141 92 140 89 172 76 172 75 140
Polygon -13840069 true false 100 135 117 157 116 188 128 186 128 160 139 133 133 133 122 152 108 129
Polygon -13840069 true false 164 135 164 191 173 191 172 141 195 191 194 129 187 127 188 168 176 133
Polygon -13840069 true false 201 131 202 188 232 188 232 134
Polygon -7500403 true true 228 165
Polygon -7500403 true true 208 144 207 175 224 172 224 147 207 145
Polygon -7500403 true true 255 140
Polygon -13840069 true false 235 137 241 188 247 188 252 150 263 187 273 187 284 134 274 134 265 177 253 137 242 179 240 130
Polygon -13840069 true false 27 128 26 189 60 174 40 158 39 153 64 137
Polygon -7500403 true true 32 136 32 148 48 139 32 137
Polygon -7500403 true true 32 170 32 182 49 173

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

newspaper
true
0
Rectangle -7500403 false true 60 90 255 195
Line -7500403 true 255 105 270 105
Line -7500403 true 270 105 270 180
Line -7500403 true 256 196 269 180
Line -7500403 true 76 106 76 148
Line -7500403 true 76 109 88 151
Line -7500403 true 89 108 89 151
Line -7500403 true 105 105 105 150
Line -7500403 true 105 105 120 105
Line -7500403 true 105 120 120 120
Line -7500403 true 105 150 120 150
Line -7500403 true 135 105 150 150
Line -7500403 true 152 151 156 107
Line -7500403 true 157 111 163 152
Line -7500403 true 165 150 180 105
Line -7500403 true 225 105 195 105
Line -7500403 true 195 105 195 135
Line -7500403 true 195 135 225 135
Line -7500403 true 225 135 225 150
Line -7500403 true 225 150 195 150

newspaper-2
true
0
Rectangle -7500403 false true 60 90 255 225
Line -7500403 true 255 105 270 105
Line -7500403 true 270 105 270 210
Line -7500403 true 256 226 269 210
Rectangle -7500403 true true 75 120 120 210
Line -7500403 true 135 120 180 120
Line -7500403 true 135 135 180 135
Line -7500403 true 135 150 180 150
Line -7500403 true 135 165 180 165
Line -7500403 true 135 180 180 180
Line -7500403 true 135 195 180 195
Line -7500403 true 135 210 180 210
Rectangle -7500403 true true 195 120 240 165
Line -7500403 true 195 180 240 180
Line -7500403 true 195 195 240 195
Line -7500403 true 195 210 240 210

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

person-adult
false
0
Rectangle -1 true false 120 90 180 180
Polygon -13345367 true false 135 90 150 105 135 180 150 195 165 180 150 105 165 90
Polygon -7500403 true true 120 90 105 90 60 195 90 210 116 154 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 183 153 210 210 240 195 195 90 180 90 150 165
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 76 172 91
Line -16777216 false 172 90 161 94
Line -16777216 false 128 90 139 94
Polygon -13345367 true false 195 225 195 300 270 270 270 195
Rectangle -13791810 true false 180 225 195 300
Polygon -14835848 true false 180 226 195 226 270 196 255 196
Polygon -13345367 true false 209 202 209 216 244 202 243 188
Line -16777216 false 180 90 150 165
Line -16777216 false 120 90 150 165

person-child
false
0
Circle -7500403 true true 65 5 80
Polygon -7500403 true true 60 90 75 195 45 285 60 300 90 300 105 225 120 300 150 300 165 285 135 195 150 90
Rectangle -7500403 true true 82 79 127 94
Polygon -7500403 true true 150 90 195 150 180 180 120 105
Polygon -7500403 true true 60 90 15 150 30 180 90 105
Circle -7500403 true true 214 138 44
Rectangle -7500403 true true 223 177 249 192
Polygon -7500403 true true 226 151
Polygon -7500403 true true 229 187 263 187 277 225 270 240 254 205 251 246 263 287 248 302 239 255 222 296 208 285 224 252 208 210 170 165 193 158 214 195 226 188 228 186 228 189

person-old
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 105 90 60 150 75 180 135 105
Rectangle -6459832 true false 228 153 236 296
Polygon -7500403 true true 195 90 240 150 225 180 165 105

person-teen
false
0
Polygon -13791810 true false 135 90 150 105 135 165 150 180 165 165 150 105 165 90
Polygon -7500403 true true 195 90 240 195 210 210 165 105
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -1 true false 100 210 130 225 145 165 85 135 63 189
Polygon -13791810 true false 90 210 120 225 135 165 67 130 53 189
Polygon -1 true false 120 224 131 225 124 210
Line -16777216 false 139 168 126 225
Line -16777216 false 140 167 76 136
Polygon -7500403 true true 105 90 60 195 90 210 135 105

person-ultraadult
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 106 90 121 195 91 285 106 300 136 300 151 225 166 300 196 300 211 285 181 195 196 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105
Polygon -11221820 true false 135 90 165 90 157 115 144 115 135 92 135 90
Polygon -11221820 true false 145 117 155 117 160 181 150 202 139 180 144 118 145 118 144 118
Polygon -6459832 true false 146 66 137 72 119 72 113 68 112 63 114 55 119 55 125 56 121 63 120 67 126 67 134 64 136 61 158 61 166 66 174 69 182 68 182 64 178 60 173 58 170 58 174 54 184 54 186 62 186 69 181 75 174 75 166 73 159 71 155 72 146 67
Circle -1 true false 122 32 16
Circle -1 true false 162 32 16
Polygon -13840069 true false 126 3 98 45 206 45 185 0 124 3

person-young
false
0
Circle -7500403 true true 113 8 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 196 92 241 152 226 182 166 107
Polygon -7500403 true true 105 90 60 150 75 180 135 105
Polygon -7500403 true true 105 30
Polygon -13345367 true false 106 44 195 44 194 37 189 25 183 15 173 5 165 2 155 2 142 1 133 2 126 9 117 18 113 25 108 34 105 44 109 35 107 45 106 42 106 45
Polygon -2674135 true false 109 44 129 60 151 74 177 78 210 77 227 71 221 58 212 54 195 44 193 42 111 43 109 44 109 48 112 47

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

television
true
0
Rectangle -7500403 false true 60 90 240 210
Line -7500403 true 165 90 210 45
Line -7500403 true 135 90 90 45
Rectangle -7500403 true true 75 105 195 195
Circle -7500403 true true 206 115 20
Circle -7500403 true true 206 151 20

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

youtube
true
0
Rectangle -2674135 true false 45 90 240 210
Polygon -2674135 true false 75 120 75 120
Polygon -1 true false 105 120 105 180 180 150 105 120
@#$#@#$#@
NetLogo 6.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
